#!/usr/bin/env bash
# 
# SCRIPT NAME:
# arch.sh
#
# AUTHOR:
# Severin Kaderli <severin@kaderli.dev>
#
# DESCRIPTION:
# Installs arch packages from the offical repositories

output::section "Arch Packages"

install-pkgbuild() {
    output::log "Installing ${1} PKGBUILD"
    cd "${INSTALL_DIR}/PKGBUILDs/${1}" || exit
    paru -Ui --noconfirm
    output::success "${1} successfully installed"

    # Mark dependencies as dependency
    paru -D --asexplicit "${1}"
    paru -D --asdeps $(pactree --linear --unique "${1}" | tail -n +2 | xargs)
}

if output::prompt "Do you want to install Arch packages?"; then
    output::log "Updating package database"
    paru -Syy |& output::debug
    output::success "Package database successfully updated"

    install-pkgbuild "severin-base"
    
    if [ "${HOST}" = "odin" ]; then
        install-pkgbuild "severin-cpu-intel"
        install-pkgbuild "severin-gpu-intel"
        install-pkgbuild "severin-gpu-nvidia"
    fi
    
    if [ "${HOST}" = "tyr" ]; then
        install-pkgbuild "severin-cpu-amd"
        install-pkgbuild "severin-gpu-amd"
        install-pkgbuild "severin-gpu-nvidia"
        install-pkgbuild "severin-plasma"
    fi
fi
